@@ -173,7 +173,7 @@ If you'd like to fiddle with the default parameters to Data::Printer, do it this
         {
             require Data::Printer;
             shift;
-            return Data::Printer::p(shift, colored => 1, quote_keys => 1);
+            return &Data::Printer::np(shift, colored => 1, quote_keys => 1);
         });
     }
 
@@ -183,6 +183,11 @@ Note the following things about the latter example:
 
 =item *
 
+We've used Data::Printer's C<np> function, which is the proper way to do it for the later versions
+of Data::Printer.  For versions prior to 0.36, use C<p> instead.
+
+=item *
+
 You B<must> put the call to C<add_func()> inside the C<import>.  That's because
 C<Debuggit::add_func> doesn't even exist until after C<Debuggit::import> has been called.  Which is,
 in turn, so that it won't hang around taking up memory when debugging is turned off.  Also, don't
@@ -206,6 +211,12 @@ would go back to being spaces.
 Remember that Debuggit is dealing only with strings until the very end, and then it uses its own
 output function.  Thus, setting Data::Printer's C<output> parameter wouldn't have any effect.
 
+=item *
+
+The seemingly extraneous C<&> before the function call disables any potential prototype
+Data::Printer is using.  It might not be necessary (depending on your DP version), but it won't hurt
+anything, and better safe than sorry.
+
 =back
 
 
